@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_eks._jsii
@@ -16,7 +16,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "eks-spot-blocks", "0.2.4", __name__[0:-6], "eks-spot-blocks@0.2.4.jsii.tgz"
+    "eks-spot-blocks", "0.2.48", __name__[0:-6], "eks-spot-blocks@0.2.48.jsii.tgz"
 )
 
 __all__ = [
